@@ -1,25 +1,27 @@
-# Copyright (C) 2005-2009 Osmo Salomaa
-#
-# This file is part of Gaupol.
-#
-# Gaupol is free software: you can redistribute it and/or modify it under the
-# terms of the GNU General Public License as published by the Free Software
-# Foundation, either version 3 of the License, or (at your option) any later
-# version.
-#
-# Gaupol is distributed in the hope that it will be useful, but WITHOUT ANY
-# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
-# A PARTICULAR PURPOSE. See the GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License along with
-# Gaupol. If not, see <http://www.gnu.org/licenses/>.
+# -*- coding: utf-8 -*-
 
-"""Reading, writing and manipulating text-based subtitle files.
+# Copyright (C) 2005 Osmo Salomaa
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
+
+"""
+Reading, writing and manipulating text-based subtitle files.
 
 :mod:`aeidon` is a Python package that provides classes and functions for
 dealing with text-based subtitle files of many different formats. Functions
 exist for reading and writing subtitle files as well as manipulating subtitle
-data, i.e. positions (times or frames) and texts. Three examples of basic use
+data, i.e. positions (times or frames) and texts. Two examples of basic use
 of the :mod:`aeidon` package follow below.
 
 Converting a file from the SubRip format to the MicroDVD format::
@@ -35,17 +37,7 @@ Making all subtitles in a file appear two seconds earlier::
 
     project = aeidon.Project()
     project.open_main("/path/to/file.srt", "utf_8")
-    project.shift_positions(None, -2.0)
-    project.save_main()
-
-Removing all blank subtitles::
-
-    project = aeidon.Project()
-    project.open_main("/path/to/file.srt", "utf_8")
-    indices = [i for i, x in enumerate(project.subtitles)
-               if not x.main_text]
-
-    project.remove_subtitles(indices)
+    project.shift_positions(None, aeidon.as_seconds(-2))
     project.save_main()
 
 :mod:`aeidon` handles positions as either times (as strings of form
@@ -67,6 +59,7 @@ accessing the subtitles directly (via :attr:`aeidon.Project.subtitles`).
 :var DATA_DIR: Path to the global data directory
 :var DATA_HOME_DIR: Path to the user's local data directory
 :var LOCALE_DIR: Path to the global locale directory
+:var RE_ANY_TAG: Regular expression for markup tags of any format
 
 :var align_methods: Enumerations for subtitle align methods
 :var documents: Enumerations for document types
@@ -76,46 +69,31 @@ accessing the subtitles directly (via :attr:`aeidon.Project.subtitles`).
 :var newlines: Enumerations for newline character types
 :var players: Enumerations for video player application types
 :var registers: Enumerations for action action reversion register types
-
-:var debug: ``True`` to perform additional run-time checks
-
-   `debug` is used in many cases at import time and should thus not be set
-   directly, but rather by setting a non-blank value, e.g. "1", to either of
-   environment variables ``AEIDON_DEBUG`` or ``GAUPOL_DEBUG``.
-
-:var re_any_tag: Regular expression for markup tags of any format
 """
 
-import os
 import re
+import sys
 
-__version__ = "0.19.2"
+__version__ = "0.91"
 
-debug = (bool(os.environ.get("AEIDON_DEBUG", "")) or
-         bool(os.environ.get("GAUPOL_DEBUG", "")))
+RUNNING_SPHINX = (sys.argv[0].endswith("autogen.py") or
+                  sys.argv[0].endswith("sphinx-build"))
 
-re_any_tag = re.compile(r"(^[/\\_]+|<.*?>|\{.*?\})")
+RE_ANY_TAG = re.compile(r"(^[/\\_]+|<.*?>|\{.*?\})")
 
 from aeidon.paths import *
+from aeidon.position import *
 from aeidon import deco
 from aeidon import i18n
 from aeidon import util
 from aeidon import temp
-from aeidon.contractual import *
 from aeidon.delegate import *
 from aeidon.singleton import *
 from aeidon.mutables import *
 from aeidon.observable import *
 from aeidon.errors import *
 from aeidon.enum import *
-from aeidon.enums.align import *
-from aeidon.enums.documents import *
-from aeidon.enums.formats import *
-from aeidon.enums.framerates import *
-from aeidon.enums.modes import *
-from aeidon.enums.newlines import *
-from aeidon.enums.players import *
-from aeidon.enums.registers import *
+from aeidon.enums import *
 from aeidon import encodings
 from aeidon import languages
 from aeidon import countries
@@ -131,8 +109,8 @@ from aeidon.subtitle import *
 from aeidon.file import *
 from aeidon import files
 from aeidon.markup import *
-from aeidon import tags
-from aeidon.converter import *
+from aeidon import markups
+from aeidon.markupconv import *
 from aeidon.pattern import *
 from aeidon.patternman import *
 from aeidon.clipboard import *
